==> apollo-annotations-js-3.4.0.jar: apollo-kotlin-apollo-annotations-js-legacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'apollo-kotlin-apollo-annotations-js-legacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'apollo-kotlin-apollo-annotations-js-legacy'.");
    }
    root['apollo-kotlin-apollo-annotations-js-legacy'] = factory(typeof this['apollo-kotlin-apollo-annotations-js-legacy'] === 'undefined' ? {} : this['apollo-kotlin-apollo-annotations-js-legacy'], kotlin);
  }
}(this, function (_, Kotlin) {
  'use strict';
  var Enum = Kotlin.kotlin.Enum;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var throwISE = Kotlin.throwISE;
  var Annotation = Kotlin.kotlin.Annotation;
  ApolloDeprecatedSince$Version.prototype = Object.create(Enum.prototype);
  ApolloDeprecatedSince$Version.prototype.constructor = ApolloDeprecatedSince$Version;
  function ApolloDeprecatedSince(version) {
    this.version = version;
  }
  function ApolloDeprecatedSince$Version(name, ordinal) {
    Enum.call(this);
    this.name$ = name;
    this.ordinal$ = ordinal;
  }
  function ApolloDeprecatedSince$Version_initFields() {
    ApolloDeprecatedSince$Version_initFields = function () {
    };
    ApolloDeprecatedSince$Version$v3_0_0_instance = new ApolloDeprecatedSince$Version('v3_0_0', 0);
    ApolloDeprecatedSince$Version$v3_0_1_instance = new ApolloDeprecatedSince$Version('v3_0_1', 1);
    ApolloDeprecatedSince$Version$v3_1_1_instance = new ApolloDeprecatedSince$Version('v3_1_1', 2);
    ApolloDeprecatedSince$Version$v3_2_1_instance = new ApolloDeprecatedSince$Version('v3_2_1', 3);
    ApolloDeprecatedSince$Version$v3_2_2_instance = new ApolloDeprecatedSince$Version('v3_2_2', 4);
    ApolloDeprecatedSince$Version$v3_2_3_instance = new ApolloDeprecatedSince$Version('v3_2_3', 5);
    ApolloDeprecatedSince$Version$v3_3_1_instance = new ApolloDeprecatedSince$Version('v3_3_1', 6);
    ApolloDeprecatedSince$Version$v3_3_2_instance = new ApolloDeprecatedSince$Version('v3_3_2', 7);
    ApolloDeprecatedSince$Version$v3_3_3_instance = new ApolloDeprecatedSince$Version('v3_3_3', 8);
  }
  var ApolloDeprecatedSince$Version$v3_0_0_instance;
  function ApolloDeprecatedSince$Version$v3_0_0_getInstance() {
    ApolloDeprecatedSince$Version_initFields();
    return ApolloDeprecatedSince$Version$v3_0_0_instance;
  }
  var ApolloDeprecatedSince$Version$v3_0_1_instance;
  function ApolloDeprecatedSince$Version$v3_0_1_getInstance() {
    ApolloDeprecatedSince$Version_initFields();
    return ApolloDeprecatedSince$Version$v3_0_1_instance;
  }
  var ApolloDeprecatedSince$Version$v3_1_1_instance;
  function ApolloDeprecatedSince$Version$v3_1_1_getInstance() {
    ApolloDeprecatedSince$Version_initFields();
    return ApolloDeprecatedSince$Version$v3_1_1_instance;
  }
  var ApolloDeprecatedSince$Version$v3_2_1_instance;
  function ApolloDeprecatedSince$Version$v3_2_1_getInstance() {
    ApolloDeprecatedSince$Version_initFields();
    return ApolloDeprecatedSince$Version$v3_2_1_instance;
  }
  var ApolloDeprecatedSince$Version$v3_2_2_instance;
  function ApolloDeprecatedSince$Version$v3_2_2_getInstance() {
    ApolloDeprecatedSince$Version_initFields();
    return ApolloDeprecatedSince$Version$v3_2_2_instance;
  }
  var ApolloDeprecatedSince$Version$v3_2_3_instance;
  function ApolloDeprecatedSince$Version$v3_2_3_getInstance() {
    ApolloDeprecatedSince$Version_initFields();
    return ApolloDeprecatedSince$Version$v3_2_3_instance;
  }
  var ApolloDeprecatedSince$Version$v3_3_1_instance;
  function ApolloDeprecatedSince$Version$v3_3_1_getInstance() {
    ApolloDeprecatedSince$Version_initFields();
    return ApolloDeprecatedSince$Version$v3_3_1_instance;
  }
  var ApolloDeprecatedSince$Version$v3_3_2_instance;
  function ApolloDeprecatedSince$Version$v3_3_2_getInstance() {
    ApolloDeprecatedSince$Version_initFields();
    return ApolloDeprecatedSince$Version$v3_3_2_instance;
  }
  var ApolloDeprecatedSince$Version$v3_3_3_instance;
  function ApolloDeprecatedSince$Version$v3_3_3_getInstance() {
    ApolloDeprecatedSince$Version_initFields();
    return ApolloDeprecatedSince$Version$v3_3_3_instance;
  }
  ApolloDeprecatedSince$Version.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'Version',
    interfaces: [Enum]
  };
  function ApolloDeprecatedSince$Version$values() {
    return [ApolloDeprecatedSince$Version$v3_0_0_getInstance(), ApolloDeprecatedSince$Version$v3_0_1_getInstance(), ApolloDeprecatedSince$Version$v3_1_1_getInstance(), ApolloDeprecatedSince$Version$v3_2_1_getInstance(), ApolloDeprecatedSince$Version$v3_2_2_getInstance(), ApolloDeprecatedSince$Version$v3_2_3_getInstance(), ApolloDeprecatedSince$Version$v3_3_1_getInstance(), ApolloDeprecatedSince$Version$v3_3_2_getInstance(), ApolloDeprecatedSince$Version$v3_3_3_getInstance()];
  }
  ApolloDeprecatedSince$Version.values = ApolloDeprecatedSince$Version$values;
  function ApolloDeprecatedSince$Version$valueOf(name) {
    switch (name) {
      case 'v3_0_0':
        return ApolloDeprecatedSince$Version$v3_0_0_getInstance();
      case 'v3_0_1':
        return ApolloDeprecatedSince$Version$v3_0_1_getInstance();
      case 'v3_1_1':
        return ApolloDeprecatedSince$Version$v3_1_1_getInstance();
      case 'v3_2_1':
        return ApolloDeprecatedSince$Version$v3_2_1_getInstance();
      case 'v3_2_2':
        return ApolloDeprecatedSince$Version$v3_2_2_getInstance();
      case 'v3_2_3':
        return ApolloDeprecatedSince$Version$v3_2_3_getInstance();
      case 'v3_3_1':
        return ApolloDeprecatedSince$Version$v3_3_1_getInstance();
      case 'v3_3_2':
        return ApolloDeprecatedSince$Version$v3_3_2_getInstance();
      case 'v3_3_3':
        return ApolloDeprecatedSince$Version$v3_3_3_getInstance();
      default:
        throwISE('No enum constant com.apollographql.apollo3.annotations.ApolloDeprecatedSince.Version.' + name);
    }
  }
  ApolloDeprecatedSince$Version.valueOf_61zpoe$ = ApolloDeprecatedSince$Version$valueOf;
  ApolloDeprecatedSince.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'ApolloDeprecatedSince',
    interfaces: [Annotation]
  };
  function ApolloExperimental() {
  }
  ApolloExperimental.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'ApolloExperimental',
    interfaces: [Annotation]
  };
  function ApolloInternal() {
  }
  ApolloInternal.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'ApolloInternal',
    interfaces: [Annotation]
  };
  function ApolloRequiresOptIn() {
  }
  ApolloRequiresOptIn.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'ApolloRequiresOptIn',
    interfaces: [Annotation]
  };
  Object.defineProperty(ApolloDeprecatedSince$Version, 'v3_0_0', {
    get: ApolloDeprecatedSince$Version$v3_0_0_getInstance
  });
  Object.defineProperty(ApolloDeprecatedSince$Version, 'v3_0_1', {
    get: ApolloDeprecatedSince$Version$v3_0_1_getInstance
  });
  Object.defineProperty(ApolloDeprecatedSince$Version, 'v3_1_1', {
    get: ApolloDeprecatedSince$Version$v3_1_1_getInstance
  });
  Object.defineProperty(ApolloDeprecatedSince$Version, 'v3_2_1', {
    get: ApolloDeprecatedSince$Version$v3_2_1_getInstance
  });
  Object.defineProperty(ApolloDeprecatedSince$Version, 'v3_2_2', {
    get: ApolloDeprecatedSince$Version$v3_2_2_getInstance
  });
  Object.defineProperty(ApolloDeprecatedSince$Version, 'v3_2_3', {
    get: ApolloDeprecatedSince$Version$v3_2_3_getInstance
  });
  Object.defineProperty(ApolloDeprecatedSince$Version, 'v3_3_1', {
    get: ApolloDeprecatedSince$Version$v3_3_1_getInstance
  });
  Object.defineProperty(ApolloDeprecatedSince$Version, 'v3_3_2', {
    get: ApolloDeprecatedSince$Version$v3_3_2_getInstance
  });
  Object.defineProperty(ApolloDeprecatedSince$Version, 'v3_3_3', {
    get: ApolloDeprecatedSince$Version$v3_3_3_getInstance
  });
  ApolloDeprecatedSince.Version = ApolloDeprecatedSince$Version;
  var package$com = _.com || (_.com = {});
  var package$apollographql = package$com.apollographql || (package$com.apollographql = {});
  var package$apollo3 = package$apollographql.apollo3 || (package$apollographql.apollo3 = {});
  var package$annotations = package$apollo3.annotations || (package$apollo3.annotations = {});
  package$annotations.ApolloDeprecatedSince = ApolloDeprecatedSince;
  package$annotations.ApolloExperimental = ApolloExperimental;
  package$annotations.ApolloInternal = ApolloInternal;
  package$annotations.ApolloRequiresOptIn = ApolloRequiresOptIn;
  Kotlin.defineModule('apollo-kotlin-apollo-annotations-js-legacy', _);
  return _;
}));

//# sourceMappingURL=apollo-kotlin-apollo-annotations-js-legacy.js.map

==> apollo-annotations-js-3.5.0.jar: apollo-kotlin-apollo-annotations-js-legacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'apollo-kotlin-apollo-annotations-js-legacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'apollo-kotlin-apollo-annotations-js-legacy'.");
    }
    root['apollo-kotlin-apollo-annotations-js-legacy'] = factory(typeof this['apollo-kotlin-apollo-annotations-js-legacy'] === 'undefined' ? {} : this['apollo-kotlin-apollo-annotations-js-legacy'], kotlin);
  }
}(this, function (_, Kotlin) {
  'use strict';
  var Enum = Kotlin.kotlin.Enum;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var throwISE = Kotlin.throwISE;
  var Annotation = Kotlin.kotlin.Annotation;
  ApolloDeprecatedSince$Version.prototype = Object.create(Enum.prototype);
  ApolloDeprecatedSince$Version.prototype.constructor = ApolloDeprecatedSince$Version;
  function ApolloDeprecatedSince(version) {
    this.version = version;
  }
  function ApolloDeprecatedSince$Version(name, ordinal) {
    Enum.call(this);
    this.name$ = name;
    this.ordinal$ = ordinal;
  }
  function ApolloDeprecatedSince$Version_initFields() {
    ApolloDeprecatedSince$Version_initFields = function () {
    };
    ApolloDeprecatedSince$Version$v3_0_0_instance = new ApolloDeprecatedSince$Version('v3_0_0', 0);
    ApolloDeprecatedSince$Version$v3_0_1_instance = new ApolloDeprecatedSince$Version('v3_0_1', 1);
    ApolloDeprecatedSince$Version$v3_1_1_instance = new ApolloDeprecatedSince$Version('v3_1_1', 2);
    ApolloDeprecatedSince$Version$v3_2_1_instance = new ApolloDeprecatedSince$Version('v3_2_1', 3);
    ApolloDeprecatedSince$Version$v3_2_2_instance = new ApolloDeprecatedSince$Version('v3_2_2', 4);
    ApolloDeprecatedSince$Version$v3_2_3_instance = new ApolloDeprecatedSince$Version('v3_2_3', 5);
    ApolloDeprecatedSince$Version$v3_3_1_instance = new ApolloDeprecatedSince$Version('v3_3_1', 6);
    ApolloDeprecatedSince$Version$v3_3_2_instance = new ApolloDeprecatedSince$Version('v3_3_2', 7);
    ApolloDeprecatedSince$Version$v3_3_3_instance = new ApolloDeprecatedSince$Version('v3_3_3', 8);
    ApolloDeprecatedSince$Version$v3_4_1_instance = new ApolloDeprecatedSince$Version('v3_4_1', 9);
  }
  var ApolloDeprecatedSince$Version$v3_0_0_instance;
  function ApolloDeprecatedSince$Version$v3_0_0_getInstance() {
    ApolloDeprecatedSince$Version_initFields();
    return ApolloDeprecatedSince$Version$v3_0_0_instance;
  }
  var ApolloDeprecatedSince$Version$v3_0_1_instance;
  function ApolloDeprecatedSince$Version$v3_0_1_getInstance() {
    ApolloDeprecatedSince$Version_initFields();
    return ApolloDeprecatedSince$Version$v3_0_1_instance;
  }
  var ApolloDeprecatedSince$Version$v3_1_1_instance;
  function ApolloDeprecatedSince$Version$v3_1_1_getInstance() {
    ApolloDeprecatedSince$Version_initFields();
    return ApolloDeprecatedSince$Version$v3_1_1_instance;
  }
  var ApolloDeprecatedSince$Version$v3_2_1_instance;
  function ApolloDeprecatedSince$Version$v3_2_1_getInstance() {
    ApolloDeprecatedSince$Version_initFields();
    return ApolloDeprecatedSince$Version$v3_2_1_instance;
  }
  var ApolloDeprecatedSince$Version$v3_2_2_instance;
  function ApolloDeprecatedSince$Version$v3_2_2_getInstance() {
    ApolloDeprecatedSince$Version_initFields();
    return ApolloDeprecatedSince$Version$v3_2_2_instance;
  }
  var ApolloDeprecatedSince$Version$v3_2_3_instance;
  function ApolloDeprecatedSince$Version$v3_2_3_getInstance() {
    ApolloDeprecatedSince$Version_initFields();
    return ApolloDeprecatedSince$Version$v3_2_3_instance;
  }
  var ApolloDeprecatedSince$Version$v3_3_1_instance;
  function ApolloDeprecatedSince$Version$v3_3_1_getInstance() {
    ApolloDeprecatedSince$Version_initFields();
    return ApolloDeprecatedSince$Version$v3_3_1_instance;
  }
  var ApolloDeprecatedSince$Version$v3_3_2_instance;
  function ApolloDeprecatedSince$Version$v3_3_2_getInstance() {
    ApolloDeprecatedSince$Version_initFields();
    return ApolloDeprecatedSince$Version$v3_3_2_instance;
  }
  var ApolloDeprecatedSince$Version$v3_3_3_instance;
  function ApolloDeprecatedSince$Version$v3_3_3_getInstance() {
    ApolloDeprecatedSince$Version_initFields();
    return ApolloDeprecatedSince$Version$v3_3_3_instance;
  }
  var ApolloDeprecatedSince$Version$v3_4_1_instance;
  function ApolloDeprecatedSince$Version$v3_4_1_getInstance() {
    ApolloDeprecatedSince$Version_initFields();
    return ApolloDeprecatedSince$Version$v3_4_1_instance;
  }
  ApolloDeprecatedSince$Version.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'Version',
    interfaces: [Enum]
  };
  function ApolloDeprecatedSince$Version$values() {
    return [ApolloDeprecatedSince$Version$v3_0_0_getInstance(), ApolloDeprecatedSince$Version$v3_0_1_getInstance(), ApolloDeprecatedSince$Version$v3_1_1_getInstance(), ApolloDeprecatedSince$Version$v3_2_1_getInstance(), ApolloDeprecatedSince$Version$v3_2_2_getInstance(), ApolloDeprecatedSince$Version$v3_2_3_getInstance(), ApolloDeprecatedSince$Version$v3_3_1_getInstance(), ApolloDeprecatedSince$Version$v3_3_2_getInstance(), ApolloDeprecatedSince$Version$v3_3_3_getInstance(), ApolloDeprecatedSince$Version$v3_4_1_getInstance()];
  }
  ApolloDeprecatedSince$Version.values = ApolloDeprecatedSince$Version$values;
  function ApolloDeprecatedSince$Version$valueOf(name) {
    switch (name) {
      case 'v3_0_0':
        return ApolloDeprecatedSince$Version$v3_0_0_getInstance();
      case 'v3_0_1':
        return ApolloDeprecatedSince$Version$v3_0_1_getInstance();
      case 'v3_1_1':
        return ApolloDeprecatedSince$Version$v3_1_1_getInstance();
      case 'v3_2_1':
        return ApolloDeprecatedSince$Version$v3_2_1_getInstance();
      case 'v3_2_2':
        return ApolloDeprecatedSince$Version$v3_2_2_getInstance();
      case 'v3_2_3':
        return ApolloDeprecatedSince$Version$v3_2_3_getInstance();
      case 'v3_3_1':
        return ApolloDeprecatedSince$Version$v3_3_1_getInstance();
      case 'v3_3_2':
        return ApolloDeprecatedSince$Version$v3_3_2_getInstance();
      case 'v3_3_3':
        return ApolloDeprecatedSince$Version$v3_3_3_getInstance();
      case 'v3_4_1':
        return ApolloDeprecatedSince$Version$v3_4_1_getInstance();
      default:
        throwISE('No enum constant com.apollographql.apollo3.annotations.ApolloDeprecatedSince.Version.' + name);
    }
  }
  ApolloDeprecatedSince$Version.valueOf_61zpoe$ = ApolloDeprecatedSince$Version$valueOf;
  ApolloDeprecatedSince.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'ApolloDeprecatedSince',
    interfaces: [Annotation]
  };
  function ApolloExperimental() {
  }
  ApolloExperimental.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'ApolloExperimental',
    interfaces: [Annotation]
  };
  function ApolloInternal() {
  }
  ApolloInternal.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'ApolloInternal',
    interfaces: [Annotation]
  };
  function ApolloRequiresOptIn() {
  }
  ApolloRequiresOptIn.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'ApolloRequiresOptIn',
    interfaces: [Annotation]
  };
  Object.defineProperty(ApolloDeprecatedSince$Version, 'v3_0_0', {
    get: ApolloDeprecatedSince$Version$v3_0_0_getInstance
  });
  Object.defineProperty(ApolloDeprecatedSince$Version, 'v3_0_1', {
    get: ApolloDeprecatedSince$Version$v3_0_1_getInstance
  });
  Object.defineProperty(ApolloDeprecatedSince$Version, 'v3_1_1', {
    get: ApolloDeprecatedSince$Version$v3_1_1_getInstance
  });
  Object.defineProperty(ApolloDeprecatedSince$Version, 'v3_2_1', {
    get: ApolloDeprecatedSince$Version$v3_2_1_getInstance
  });
  Object.defineProperty(ApolloDeprecatedSince$Version, 'v3_2_2', {
    get: ApolloDeprecatedSince$Version$v3_2_2_getInstance
  });
  Object.defineProperty(ApolloDeprecatedSince$Version, 'v3_2_3', {
    get: ApolloDeprecatedSince$Version$v3_2_3_getInstance
  });
  Object.defineProperty(ApolloDeprecatedSince$Version, 'v3_3_1', {
    get: ApolloDeprecatedSince$Version$v3_3_1_getInstance
  });
  Object.defineProperty(ApolloDeprecatedSince$Version, 'v3_3_2', {
    get: ApolloDeprecatedSince$Version$v3_3_2_getInstance
  });
  Object.defineProperty(ApolloDeprecatedSince$Version, 'v3_3_3', {
    get: ApolloDeprecatedSince$Version$v3_3_3_getInstance
  });
  Object.defineProperty(ApolloDeprecatedSince$Version, 'v3_4_1', {
    get: ApolloDeprecatedSince$Version$v3_4_1_getInstance
  });
  ApolloDeprecatedSince.Version = ApolloDeprecatedSince$Version;
  var package$com = _.com || (_.com = {});
  var package$apollographql = package$com.apollographql || (package$com.apollographql = {});
  var package$apollo3 = package$apollographql.apollo3 || (package$apollographql.apollo3 = {});
  var package$annotations = package$apollo3.annotations || (package$apollo3.annotations = {});
  package$annotations.ApolloDeprecatedSince = ApolloDeprecatedSince;
  package$annotations.ApolloExperimental = ApolloExperimental;
  package$annotations.ApolloInternal = ApolloInternal;
  package$annotations.ApolloRequiresOptIn = ApolloRequiresOptIn;
  Kotlin.defineModule('apollo-kotlin-apollo-annotations-js-legacy', _);
  return _;
}));

//# sourceMappingURL=apollo-kotlin-apollo-annotations-js-legacy.js.map
